Class: Google::Apis::IamV2::GoogleIamV3betaOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v2/classes.rb,
lib/google/apis/iam_v2/representations.rb,
lib/google/apis/iam_v2/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleIamV3betaOperationMetadata

Returns a new instance of GoogleIamV3betaOperationMetadata.



708
709
710
# File 'lib/google/apis/iam_v2/classes.rb', line 708

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


672
673
674
# File 'lib/google/apis/iam_v2/classes.rb', line 672

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


677
678
679
# File 'lib/google/apis/iam_v2/classes.rb', line 677

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


682
683
684
# File 'lib/google/apis/iam_v2/classes.rb', line 682

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have Operation. error value with a google.rpc.Status.code of 1, corresponding to Code. CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


690
691
692
# File 'lib/google/apis/iam_v2/classes.rb', line 690

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


696
697
698
# File 'lib/google/apis/iam_v2/classes.rb', line 696

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the Corresponds to the JSON property target

Returns:

  • (String)


701
702
703
# File 'lib/google/apis/iam_v2/classes.rb', line 701

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


706
707
708
# File 'lib/google/apis/iam_v2/classes.rb', line 706

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



713
714
715
716
717
718
719
720
721
# File 'lib/google/apis/iam_v2/classes.rb', line 713

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end